<?php

namespace Garradin;

use Garradin\Files\Files;
use Garradin\Entities\Files\File;
use Garradin\Plugin\RecusFiscaux\Utils;

$session->requireAccess($session::SECTION_CONFIG, $session::ACCESS_ADMIN);
$art_sel  = f('articlesCGI') ? : [];
$taux_sel = f('tauxReduction') ? : [];
$noms_sel = f('champsNom') ? : [];

// récupérer les champs des noms 
$champsNom = Utils::getChampsNom($config, $plugin);

if (f('save') && $form->check('recusfiscaux_config'))
{
    try {
        // objet de l'association
        $plugin->setConfig('objet_asso', trim(f('objet_asso')));

        // articles du CGI
        $confArticles = $plugin->getConfig('articlesCGI');
        // effacer l'ancienne configuration
        for ($i = 0; $i < count($confArticles); ++$i) {
            $confArticles[$i]->valeur = 0;
        }
        // et copier la nouvelle
        foreach ($art_sel as $article) {
            $confArticles[$article]->valeur = 1;
        }
        $plugin->setConfig("articlesCGI", $confArticles);

        // taux de réduction
        $confTaux = $plugin->getConfig('reduction');
        // effacer l'ancienne configuration
        for ($i = 0; $i < count($confTaux); ++$i) {
            $confTaux[$i]->valeur = 0;
        }
        // et copier la nouvelle
        foreach ($taux_sel as $taux) {
            $confTaux[$taux]->valeur = 1;
        }
        $plugin->setConfig("reduction", $confTaux);

        // nom, fonction et signature du responsable
        $plugin->setConfig('nom_responsable', trim(f('nom_responsable')));
        $plugin->setConfig('fonction_responsable', trim(f('fonction_responsable')));
        if (isset($_SESSION['sig_file']) && count($_SESSION['sig_file']) > 0)
        {
            // supprimer la signature précédente, si besoin
            if (null !== $plugin->getConfig('signature'))
            {
                $sig_file = \Garradin\Files\Files::get($plugin->getConfig('signature'));
                if (null !== $sig_file) {
                    $sig_file->delete();
                }
            }
            // puis installer la nouvelle
            $plugin->setConfig('signature', $_SESSION['sig_file'][0]->path);
        }

        // autres informations
        // ville
        $plugin->setConfig('ville_asso', trim(f('ville_asso')));

        // champs pour le nom et prénom
        foreach ($champsNom as $nom => $champ)
        {
            $champ->position = 0;
        }
        $i = -count($noms_sel);
        foreach ($noms_sel as $nom)
        {
            $champsNom[$nom]->position = $i++;
        }
        $plugin->setConfig('champsNom', $champsNom);

        \Garradin\Utils::redirect(PLUGIN_URL . 'config.php?ok');
    }
    catch (UserException $e)
    {
        $form->addError($e->getMessage());
    }
}

// trier les champs de nom pour l'affichage
uasort($champsNom, function ($a, $b)
{
    return $a->position - $b->position;
});

$tpl->assign('ok', qg('ok') !== null);
$path = qg('path') ?: File::CONTEXT_CONFIG;
$tpl->assign('path', $path);
$tpl->assign('default_signature', \Garradin\WWW_URL . "plugin/recusfiscaux/default_signature.png");
$tpl->assign('plugin_config', $plugin->getConfig());
$tpl->assign('champsNom', $champsNom);
$tpl->assign('plugin_css', ['style.css']);
$tpl->display(PLUGIN_ROOT . '/templates/config.tpl');
